package com.xdja.flutter.bridge

import android.content.Context
import android.text.TextUtils
import androidx.annotation.NonNull;
import com.xdja.sslvpn.api.VpnApi50Impl
import com.xdja.uaac.api.TokenCallback
import com.xdja.uaac.api.UaacApi

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** BridgePlugin */
public class BridgePlugin : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel
    private lateinit var context: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "bridge")
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.applicationContext
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            FUN_GET_PLATFORM_VERSION -> getPlatformVersion(result)
            FUN_GET_UAAC_TOKEN -> getUaacToken(result)
            FUN_GET_SAFE_CARD_ID -> getSafeCardId(result)
            FUN_UAAC_LOGOUT -> uaacLogout(result)
            else -> result.notImplemented()

        }
    }

    private fun getSafeCardId(@NonNull result: Result) {
        var cardId = VpnApi50Impl(context).cardID
        if (!TextUtils.isEmpty(cardId)) {
            result.success(cardId)
        } else {
            result.error("", "获取安全卡id失败", null)
        }
    }

    private fun getUaacToken(@NonNull result: Result) {
        UaacApi.getToken(context, object : TokenCallback {
            override fun onSuccess(token: String?, isSafeClientConnected: Boolean) {
                result.success(token)
            }

            override fun onError(errorMsg: String?) {
                result.error("", errorMsg, null)
            }
        })
    }

    private fun uaacLogout(@NonNull result: Result) {
        var flag = UaacApi.logoutUaac(context)
        if (flag != 0) {
            result.success(true)
        } else {
            result.error("", "统一认证失败，无删除token权限", null)
        }
    }

    private fun getPlatformVersion(@NonNull result: Result) {
        result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
